/*
 * argument_parsing.h --prototypes functions required for parsing arguments from
 * command line and placing these into the program stack structure.
 *
 * Authored by Joshua Saxby
 */
#ifndef USERPROG_ARGUMENT_PARSING_H
#define USERPROG_ARGUMENT_PARSING_H


// some macros for argument length and count limits
// TODO: decide how many arguments we want --is 255 the standard number?
#define USERPROG_ARGV_COUNT 255
// TODO: clarify what a sensible value for this is
#define USERPROG_RAW_ARGV_LENGTH 255

/*
 * Given a string containing the command invoking the program `command_line`
 * and an array of C strings (pointer to `char* argv[]`), parse `command_line`
 * into individual arguments, populate `argv` with these and return the number
 * of arguments that were parsed (this is the value that can be used for `argc`).
 */
int parse_arguments(const char* command_line, char**argv);

/*
 * Given stack pointer `esp`, argument count `argc` and arguments array `argv`,
 * Populates the stack pointed to by the stack pointer with the given arguments.
 * esp is the initial stack pointer from process.c,
 * I have used stackPointer as the name as that makes sense inside,
 * populate_stack, in process.c esp has been renamed to initial_stack_pointer
 */
void populate_stack(void** stack_pointer, int argc, char** argv);

#endif /* userprog/argument_parsing.h */
