/*
 * File Descriptors mapper
 *
 * Authored by Joshua Saxby
 */
#include <stddef.h>
#include "filesys/filesys.h"
#include "system_calls.h"

// this means we can't have more than 255 open file handles at a time
#define MAX_FILE_POINTERS 255

static struct file* FILE_POINTERS_MAP[MAX_FILE_POINTERS] = {0};

struct file * get_associated_file_pointer(int fd) {
    switch (fd) {
    case 0: // keyboard (stdin)
    case 1: // console (stdout)
    case 2: // console (stderr)
        return NULL;
    default:
        return FILE_POINTERS_MAP[fd - 3]; // exclude special fds
    }
}

int associate_new_file_descriptor(struct file* file_pointer) {
    // if we have been passed NULL, refuse (it's silly!)
    if (file_pointer == NULL) return -1;
    // find the first decriptor which points to NULL
    for (size_t i = 0; i < MAX_FILE_POINTERS; i++) {
        if (FILE_POINTERS_MAP[i] == NULL) {
            FILE_POINTERS_MAP[i] = file_pointer;
            return i + 3; // exclude special fds
        }
    }
    // if we got here, we've run out of spare slots, return failure
    return -1;
}

bool disassociate_file_descriptor(int fd) {
    // clear the descriptor to NULL
    switch (fd) {
    case 0: // keyboard (stdin)
    case 1: // console (stdout)
    case 2: // console (stderr)
        return false;
    default:
        if (FILE_POINTERS_MAP[fd - 3] != NULL) { // exclude special fds
            FILE_POINTERS_MAP[fd - 3] = NULL;
            return true;
        } else {
            return false;
        }
    }
}
