/*
* Changes the next byte to be read or written in open file fd to position, 
* Expressed in bytes from the beginning of the file. (Thus, a position of 0
* Is the files start.)
*
* Authored by Alex Stratford
*/

#include "system_calls.h"
#include <stddef.h> // Dependency for NULL
#include "threads/interrupt.h" // Dependency for intr_frame struct
#include "filesys/file.h" // Dependency for file struct and file_seek function

void syscall_seek(struct intr_frame *f) {
	// pop off first int argument from interrupt frame
	int file_descriptor = *((int*)f->esp + 1);
	// pop off second int argument from interrupt frame
	unsigned file_pos = *((unsigned*)((int*)f->esp + 2));
	struct file *file = get_associated_file_pointer(file_descriptor);
	if (file == NULL) { // Checking if file is empty or non-existent
		return;
	}
	// Seek through the file
	file_seek(file, file_pos);
}
